pub struct Instance { /* private fields */ }
Instance holds the description of R1CS matrices and a hash of the matrices

Implementations

Constructs a new Instance and an associated satisfying assignment

Checks if a given R1CSInstance is satisfiable with a given variables and inputs assignments

Constructs a new synthetic R1CS Instance and an associated satisfying assignment