Struct libspartan::Instance
source · [−]pub struct Instance { /* private fields */ }Expand description
Instance holds the description of R1CS matrices
Implementations
sourceimpl Instance
impl Instance
sourcepub fn new(
num_cons: usize,
num_vars: usize,
num_inputs: usize,
A: &[(usize, usize, [u8; 32])],
B: &[(usize, usize, [u8; 32])],
C: &[(usize, usize, [u8; 32])]
) -> Result<Instance, R1CSError>
pub fn new(
num_cons: usize,
num_vars: usize,
num_inputs: usize,
A: &[(usize, usize, [u8; 32])],
B: &[(usize, usize, [u8; 32])],
C: &[(usize, usize, [u8; 32])]
) -> Result<Instance, R1CSError>
Constructs a new Instance and an associated satisfying assignment
sourcepub fn is_sat(
&self,
vars: &VarsAssignment,
inputs: &InputsAssignment
) -> Result<bool, R1CSError>
pub fn is_sat(
&self,
vars: &VarsAssignment,
inputs: &InputsAssignment
) -> Result<bool, R1CSError>
Checks if a given R1CSInstance is satisfiable with a given variables and inputs assignments
sourcepub fn produce_synthetic_r1cs(
num_cons: usize,
num_vars: usize,
num_inputs: usize
) -> (Instance, VarsAssignment, InputsAssignment)
pub fn produce_synthetic_r1cs(
num_cons: usize,
num_vars: usize,
num_inputs: usize
) -> (Instance, VarsAssignment, InputsAssignment)
Constructs a new synthetic R1CS Instance and an associated satisfying assignment