Struct libspartan::Instance [−][src]
pub struct Instance { /* fields omitted */ }Expand description
Instance holds the description of R1CS matrices
Implementations
Constructs a new Instance and an associated satisfying assignment
pub fn is_sat(
&self,
vars: &VarsAssignment,
inputs: &InputsAssignment
) -> Result<bool, R1CSError>
pub fn is_sat(
&self,
vars: &VarsAssignment,
inputs: &InputsAssignment
) -> Result<bool, R1CSError>
Checks if a given R1CSInstance is satisfiable with a given variables and inputs assignments
pub fn produce_synthetic_r1cs(
num_cons: usize,
num_vars: usize,
num_inputs: usize
) -> (Instance, VarsAssignment, InputsAssignment)
pub fn produce_synthetic_r1cs(
num_cons: usize,
num_vars: usize,
num_inputs: usize
) -> (Instance, VarsAssignment, InputsAssignment)
Constructs a new synthetic R1CS Instance and an associated satisfying assignment